def sum(x,y):
    print("sum"," =",(x+y))
    
def subtract(x,y):
    print("difference"," =",(x-y))
    
def divide(x,y):
    print("division"," =",(x/y))
    
def multiply(x,y):
    print("multiplication"," =",(x/y))    
    
    
    
    
  
    