from setuptools import setup

setup(
  name='djcalcilib',
  version='0.0.1',
  description='A basic calculator',
  author='dasham',
  zip_safe=False,
  packages=['djcalcilib']
  
)
                                                                   